@@ -508,6 +508,9 @@ class OTSProtoBufferEncoder(object):
         if field_schema.vector_options is not None:
             self._make_vector_options(proto.vector_options, field_schema.vector_options)
 
+        if field_schema.json_type is not None:
+            proto.json_type = self._get_enum(field_schema.json_type)
+
     def _make_vector_options(self, proto_vector_options, vector_options):
         if vector_options.data_type is not None:
             proto_vector_options.data_type = self._get_enum(vector_options.data_type)
@@ -702,6 +705,44 @@ class OTSProtoBufferEncoder(object):
                     )
             proto.allow_update = table_options.allow_update
 
+    def _make_sse_spec(self, proto, sse_spec):
+        if not isinstance(sse_spec, SSESpecification):
+            raise OTSClientError(
+                "sse_spec should be an instance of SSESpecification, not %s"
+                % sse_spec.__class__.__name__
+            )
+        if sse_spec.enable is not None:
+            if not isinstance(sse_spec.enable, bool):
+                raise OTSClientError(
+                    "enable should be an instance of bool, not %s"
+                    % sse_spec.enable.__class__.__name__
+                    )
+            proto.enable = sse_spec.enable
+
+        if sse_spec.key_type is not None:
+            if not isinstance(sse_spec.key_type, int):
+                raise OTSClientError(
+                    "key_type should be an instance of int, not %s"
+                    % sse_spec.key_type.__class__.__name__
+                    )
+            proto.key_type = sse_spec.key_type
+
+        if sse_spec.key_id is not None:
+            if not isinstance(sse_spec.key_id, str):
+                raise OTSClientError(
+                    "key_id should be an instance of str, not %s"
+                    % sse_spec.key_id.__class__.__name__
+                    )
+            proto.key_id = sse_spec.key_id
+
+        if sse_spec.role_arn is not None:
+            if not isinstance(sse_spec.role_arn, str):
+                raise OTSClientError(
+                    "role_arn should be an instance of str, not %s"
+                    % sse_spec.role_arn.__class__.__name__
+                    )
+            proto.role_arn = sse_spec.role_arn
+
     def _make_capacity_unit(self, proto, capacity_unit):
 
         if not isinstance(capacity_unit, CapacityUnit):
@@ -865,12 +906,13 @@ class OTSProtoBufferEncoder(object):
             proto.index_type = pb2.IT_LOCAL_INDEX
             proto.index_update_mode = pb2.IUM_SYNC_INDEX
 
-    def _encode_create_table(self, table_meta, table_options, reserved_throughput, secondary_indexes):
+    def _encode_create_table(self, table_meta, table_options, reserved_throughput, sse_spec, secondary_indexes):
         proto = pb2.CreateTableRequest()
         self._make_table_meta(proto.table_meta, table_meta)
         self._make_reserved_throughput(proto.reserved_throughput, reserved_throughput)
         self._make_table_options(proto.table_options, table_options)
-
+        if sse_spec is not None:
+            self._make_sse_spec(proto.sse_spec, sse_spec)
         for secondary_index in secondary_indexes:
             self._make_secondary_index(proto.index_metas.add(), secondary_index)
         return proto
@@ -1046,10 +1088,11 @@ class OTSProtoBufferEncoder(object):
 
         return proto
 
-    def _encode_describe_search_index(self, table_name, index_name):
+    def _encode_describe_search_index(self, table_name, index_name, include_sync_stat):
         proto = search_pb2.DescribeSearchIndexRequest()
         proto.table_name = self._get_unicode(table_name)
         proto.index_name = self._get_unicode(index_name)
+        proto.include_sync_stat = include_sync_stat
 
         return proto
 
@@ -1148,8 +1191,7 @@ class OTSProtoBufferEncoder(object):
         if query.weight is not None:
             proto.weight = query.weight
 
-        if query.minimum_should_match is not None:
-            proto.minimum_should_match = query.minimum_should_match
+        self._encode_minimum_should_match(query, proto)
 
         if query.operator is not None:
             proto.operator = search_pb2.OR if (query.operator == QueryOperator.OR) else search_pb2.AND
@@ -1218,8 +1260,11 @@ class OTSProtoBufferEncoder(object):
             q_proto = proto.should_queries.add()
             self._make_query(q_proto, q)
 
-        if query.minimum_should_match is not None:
-            proto.minimum_should_match = query.minimum_should_match
+        self._encode_minimum_should_match(query, proto)
+
+        if query.weight is not None:
+            proto.weight = query.weight
+
         return proto.SerializeToString()
 
     def _encode_nested_query(self, query):
@@ -1320,8 +1365,40 @@ class OTSProtoBufferEncoder(object):
         if query.filter is not None:
             self._make_query(proto.filter, query.filter)
 
+        if query.min_score is not None:
+            proto.min_score = query.min_score
+
+        if query.num_candidates is not None:
+            proto.num_candidates = query.num_candidates
+
         return proto.SerializeToString()
 
+    def _encode_dis_max_query(self, query):
+        proto = search_pb2.DisMaxQuery()
+        for q in query.queries:
+            q_proto = proto.queries.add()
+            self._make_query(q_proto, q)
+
+        if query.tie_breaker is not None:
+            proto.tie_breaker = query.tie_breaker
+
+        if query.weight is not None:
+            proto.weight = query.weight
+
+        return proto.SerializeToString()
+
+    def _encode_minimum_should_match(self, query, proto):
+        if query.minimum_should_match is not None:
+            if isinstance(query.minimum_should_match, int):
+                proto.minimum_should_match = query.minimum_should_match
+            elif isinstance(query.minimum_should_match, str):
+                proto.new_minimum_should_match = query.minimum_should_match
+                # for compatibility, send both new and old version
+                if query.minimum_should_match.isdigit():
+                    proto.minimum_should_match = int(query.minimum_should_match)
+            else:
+                raise OTSClientError("minimum_should_match must be an integer or string")
+
     def _make_query(self, proto, query):
         if isinstance(query, MatchQuery):
             proto.type = search_pb2.MATCH_QUERY
@@ -1371,6 +1448,9 @@ class OTSProtoBufferEncoder(object):
         elif isinstance(query, KnnVectorQuery):
             proto.type = search_pb2.KNN_VECTOR_QUERY
             proto.query = self._encode_knn_vector_query(query)
+        elif isinstance(query, DisMaxQuery):
+            proto.type = search_pb2.DIS_MAX_QUERY
+            proto.query = self._encode_dis_max_query(query)
         else:
             raise OTSClientError(
                 "Invalid query type: %s"
